from django import template
from django.db.models import QuerySet

register = template.Library()


@register.inclusion_tag("bookmarks/items_to_load.html", takes_context=True)
def populate_bookmark_items(context, qs: QuerySet):
    return {"items_to_load": qs, "user_profile": context["user_profile"]}



# Generated by Django 4.0.1 on 2022-02-04 08:07

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("examples", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="samplequote",
            name="book",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="quotes",
                to="examples.samplebook",
            ),
        ),
    ]
